@@ -604,12 +604,13 @@ class PartitionDistributive(Distributive):
                         'ext4':'/sbin/mkfs.ext4 %s %s',
                         'jfs':'/sbin/mkfs.jfs %s -f %s',
                         'reiserfs':'/sbin/mkfs.reiserfs %s -f %s',
-                        'btrfs':'/sbin/mkfs.btrfs %s %s',
+                        'btrfs':'/sbin/mkfs.btrfs -f %s %s',
                         'nilfs2':'/sbin/mkfs.nilfs2 %s %s',
                         'xfs':'/sbin/mkfs.xfs %s -f %s',
                         'vfat':'/usr/sbin/mkfs.vfat %s -F 32 %s',
                         'ntfs-3g':'/usr/sbin/mkfs.ntfs %s -FQ %s',
                         'ntfs':'/usr/sbin/mkfs.ntfs %s -FQ %s',
+                        'uefi':'/usr/sbin/mkfs.vfat %s %s',
                         'swap':'/sbin/mkswap %s'
     }
     labelForUtilities = { 'ext2':'-L %s',
@@ -780,14 +781,16 @@ class PartitionDistributive(Distributive):
                              self.multipartition.getPartitionTable() + \
                              [self.partitionTable])
         # get partition which need format
-        formatPartitions = map(lambda x: (x[FS],x[DEV]),
+        formatPartitions = map(lambda x: (x[FS],x[DEV],x[NEWID]),
                            filter(lambda x: x[NEEDFORMAT] and x[FS]!="bind",
                            dataPartitions))
         # format all get partition
-        for fileSystem, dev in formatPartitions:
+        for fileSystem, dev, newID in formatPartitions:
             if fileSystem=="swap":
                 self.formatSwapPartition(dev)
             else:
+                if newID == "EF00":
+                    fileSystem = "uefi"
                 if dev == self.partition:
                     self.formatPartition(dev, format=fileSystem,
                                          label=self.rootLabel)
