@@ -350,7 +350,7 @@ class Install:
             newModuleName = defaultGL
         curModuleName = map(lambda x:x.strip().rpartition('=')[-1].strip('"\''),
                    filter(lambda x: x.startswith("OPENGL_PROFILE="),
-                          open(openGLenv,'r')))
+                          readFile(openGLenv)))
         curModuleName = curModuleName[-1] if curModuleName else ""
         if curModuleName == newModuleName:
             return True
@@ -393,17 +393,19 @@ class Install:
             raise InstallError(("Unable to change the I/O scheduler"))
         return True
 
-    def autopartition(self,table,devices,data,lvm,lvm_vgname,bios_grub):
+    def autopartition(self,table,devices,data,lvm,lvm_vgname,bios_grub,
+                      bios_grub_size):
         """
         Авторазметка диска с таблицей разделов 'table', диски указываются
         'device', параметры таблицы 'data', 'lvm' использование LVM,
         'lvm_vgname' название группы томов LVM, bios_grub - создавать
-        bios_grub раздел
+        bios_grub раздел, bios_grub_size - раздел bios grub раздела в байтах
         """
         ap = AutoPartition()
         ap.clearLvm(devices,self.clVars)
         ap.clearRaid(devices,self.clVars)
-        ap.recreateSpace(table,devices,data,lvm,lvm_vgname,bios_grub)
+        ap.recreateSpace(table,devices,data,lvm,
+                         lvm_vgname,bios_grub,bios_grub_size)
         return True
 
     def format(self,target):
