@@ -293,7 +293,7 @@ class VariableClImageFilename(Variable,DistroRepository):
     def check(self,isoimage):
         """Set image file"""
         if self.Get('cl_action') == 'system' and not isoimage:
-            raise VariableError(_("Need to choice distribute image"))
+            raise VariableError(_("You need to select a distribution image"))
         imageData = Distributive().getInfo(isoimage)
         if not("os_linux_shortname" in imageData and \
                imageData.get('os_linux_build','') and \
