@@ -47,21 +47,17 @@ class UserHelper:
         """
         if self.Get('os_install_root_type') == 'flash':
             return _("User configuration unavailable for Flash install")
-        if self.Get('os_install_x11_server_set') == 'no' and self.xorg_need:
+        if self.Get('os_install_x11_server_set') == 'off' and self.xorg_need:
             return _("Autologin is available for Xorg sessions only")
         return ""
 
-class VariableOsInstallScratch(Variable):
+class VariableOsInstallScratch(ReadonlyVariable):
     """
     Install system in scratch mode
     """
     type  = "bool"
     opt = ['--build']
 
-    def init(self):
-        self.label = _("Builder mode")
-        self.help = _("build installation")
-
     def get(self):
         # for installation default - normal system
         if self.Get('cl_action') == 'system':
@@ -69,25 +65,6 @@ class VariableOsInstallScratch(Variable):
         else:
             return self.Get('os_scratch')
 
-    def check(self,value):
-        if value == "on":
-            # scratch not use for falsh and multipartition
-            if self.Get('os_install_root_type') == "flash":
-                raise VariableError(
-                    _("Flash install does not support the builder mode"))
-            if filter(lambda x: not x in ('/','swap','/boot/efi'), 
-                      self.Get('os_install_disk_mount')):
-                raise VariableError(
-                    _("The builder mode does not support "
-                      "multipartition install"))
-
-    def uncompatible(self):
-        """
-        Unavailable for flash installation
-        """
-        if self.Get('os_install_root_type') == 'flash':
-            return _("Flash install does not support the builder mode")
-
 class VariableOsFormatType(ReadonlyVariable):
     """
     Filesystem format support by calcualte-install
@@ -504,11 +481,13 @@ class VariableOsInstallMdadmSet(ReadonlyVariable):
 class VariableClChrootGrub(ReadonlyVariable):
     """
     Chroot for grub-mkconfig
-    TODO: check for install scratch system.
     """
     def get(self):
         if self.Get('os_install_scratch') == "on":
-            return path.join(self.Get('cl_chroot_path'),"mnt/scratch")
+            if self.Get('cl_action') == 'system':
+                return self.Get('cl_target').mdirectory
+            else:
+                return path.join(self.Get('cl_chroot_path'),"mnt/scratch")
         else:
             return self.Get('cl_chroot_path')
 
@@ -690,86 +669,41 @@ class VariableOsInstallGrubTerminal(Variable):
             return _("Grub configuration unavailable for Flash install")
         return ""
 
-class VariableOsAudioData(ReadonlyTableVariable):
+class PackageCheckHelper(ReadonlyVariable):
     """
-    Information about audio cards
-    """
-    source = ['os_audio_id',
-              'os_audio_name']
-
-    def get(self,hr=False):
-        """LVM hash"""
-        aplay = getProgPath('/usr/bin/aplay')
-        if not aplay:
-            return [[]]
-        entry = re.compile('^card (\d+): ([^:]+)')
-        return tuple(map(lambda x:x.groups(),
-               filter(None,map(entry.search,
-               process(aplay,'-l')))))
-
-    setValue = Variable.setValue
-
-class VariableOsAudioId(FieldValue,ReadonlyVariable):
-    """
-    Order Id of audio card
-    """
-    type = "list"
-    source_variable = "os_audio_data"
-    column = 0
-
-class VariableOsAudioName(FieldValue,ReadonlyVariable):
-    """
-    Name of audio card
-    """
-    type = "list"
-    source_variable = "os_audio_data"
-    column = 1
-
-class VariableOsAudioDefaultSet(ReadonlyVariable):
-    """
-    Force write in config 0
+    Конструктор для переменных проверки установлен ли пакет
     """
+    image = False
+    package = None
     type = "bool"
 
     def get(self):
-        res = self.Select('os_audio_id',where='os_audio_name',
-                              notlike='HDMI',limit=1)
-        audioDefault = self.Get('os_audio_default')
-        if audioDefault != '0' or \
-            res and res != "0" and audioDefault == '0':
-            return 'on'
-        return 'off'
+        try:
+            if self.image:
+                image = self.Get('cl_image')
+                if image:
+                    with image as distr:
+                        distrPath = image.getDirectory()
+                        if isPkgInstalled(self.package,prefix=distrPath):
+                            return "on"
+            else:
+                if isPkgInstalled(self.package):
+                    return "on"
+        except:
+            pass
+        return "off"
 
-class VariableOsAudioDefault(Variable):
+
+class VariableOsInstallAlsaSet(PackageCheckHelper):
     """
-    Current default audio card
+    Установлен ли media-sound/alsa-utils
     """
-    type  = "choice"
-    opt = ['--audio']
+    image = True
+    package = "media-sound/alsa-utils"
 
-    def init(self):
-        self.label = _("Default audio card")
-        self.help = _("set the default audio")
-
-    def get(self):
-        defaultCardRe = re.compile('defaults.ctl.card\s+(\d+)')
-        entry = defaultCardRe.search(readFile('/etc/asound.conf'))
-        if entry and entry.groups()[0] in self.Get('os_audio_id'):
-            return entry.groups()[0]
-        res = self.Select('os_audio_id',where='os_audio_name',
-                          notlike='HDMI',limit=1)
-        return res or '0'
-
-    def choice(self):
-        data = self.Get('os_audio_data')
-        if data and data[0]:
-            return self.Get('os_audio_data')
-        return []
-
-    def uncompatible(self):
-        """
-        Audio setting up unavailable for flash installation
-        """
-        if self.Get('os_install_root_type') == 'flash':
-            return _("Audio configuration unavailable for Flash install")
-        return ""
+class VariableOsInstallX11ServerSet(PackageCheckHelper):
+    """
+    Установлен ли x11-base/xorg-server
+    """
+    image = True
+    package = "x11-base/xorg-server"
