@@ -69,15 +69,17 @@ class Wsdl(WsdlBase):
                         'cl_image_new_only')),
             lambda group:group(_("Allocate drive space"),
                 normal=('cl_autopartition_set',),
-                expert=('cl_autopartition_scheme','cl_autopartition_device',
-                        'cl_autopartition_table','cl_autopartition_root_size'),
+                expert=('cl_autopartition_scheme',
+                        'cl_autopartition_table','cl_autopartition_root_size',
+                        'cl_autopartition_swap_size',
+                        'cl_autopartition_device'),
                 expert_label=_("Click to set up autopartition options")),
             lambda group:group(_("Mount points"),
                 normal=('os_location_data',),
                 hide=('os_location_data','os_install_mbr','os_install_uefi_set'),
                 brief_force=('os_location_brief_data','os_install_bootloader',
                              'os_install_uefi_set'),
-                expert=('os_install_scratch','cl_uuid_set',
+                expert=('cl_uuid_set',
                         'os_install_root_type',
                         'os_install_mbr',
                         'os_install_uefi_set',
